@@ -94,7 +94,8 @@ dim.SpatialLinesDataFrame = function(x) dim(x@data)
 
 setMethod("split", "SpatialLinesDataFrame", split.data.frame)
 
-print.SpatialLinesDataFrame = function(x, ..., digits = 6, asWKT = .asWKT)
+print.SpatialLinesDataFrame = function(x, ..., digits = getOption("digits"), 
+		asWKT = .asWKT)
 	print(data.frame(asWKTSpatialLines(x, digits), x@data),...)
 
 setMethod("geometry", "SpatialLinesDataFrame",
